@@ -172,13 +172,15 @@ class BayesianOptimizer:
         """
         self.bestParametersByRegressor = dict()
         bestParameters = {"regressor": None, "score": float("inf"), "parameters": None}
-        loadedObjective = partial(
-            use_named_args(hyperparameterSpaces)(objectiveToMinimize),
-            **{
-                "model": model,
-                "trainingData": trainingData,
-                "trainingLabels": trainingLabels,
-            },
+        loadedObjective = use_named_args(hyperparameterSpaces)(
+            partial(
+                objectiveToMinimize,
+                **{
+                    "model": model,
+                    "trainingData": trainingData,
+                    "trainingLabels": trainingLabels,
+                },
+            )
         )
         optimizedResultList = []
         hyperparameterNames = [parameter.name for parameter in hyperparameterSpaces]
